You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@kylin.apache.org by li...@apache.org on 2015/03/14 01:03:09 UTC

[1/3] incubator-kylin git commit: smaller hbase regions to speed up cube build

Repository: incubator-kylin
Updated Branches:
  refs/heads/0.6 753e16f53 -> 07381b832


smaller hbase regions to speed up cube build


Project: http://git-wip-us.apache.org/repos/asf/incubator-kylin/repo
Commit: http://git-wip-us.apache.org/repos/asf/incubator-kylin/commit/bfd321d8
Tree: http://git-wip-us.apache.org/repos/asf/incubator-kylin/tree/bfd321d8
Diff: http://git-wip-us.apache.org/repos/asf/incubator-kylin/diff/bfd321d8

Branch: refs/heads/0.6
Commit: bfd321d8de0ccb6bc5532d907ee9a60a9f3bb9ca
Parents: 753e16f
Author: Li, Yang <ya...@ebay.com>
Authored: Tue Mar 10 17:10:43 2015 +0800
Committer: Li, Yang <ya...@ebay.com>
Committed: Tue Mar 10 17:10:43 2015 +0800

----------------------------------------------------------------------
 .../job/hadoop/cube/RangeKeyDistributionReducer.java         | 8 ++++----
 1 file changed, 4 insertions(+), 4 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/incubator-kylin/blob/bfd321d8/job/src/main/java/com/kylinolap/job/hadoop/cube/RangeKeyDistributionReducer.java
----------------------------------------------------------------------
diff --git a/kylin.sh b/kylin.sh
index 0e0f5aa..00fd7cb 100755
--- a/kylin.sh
+++ b/kylin.sh
@@ -6,6 +6,7 @@ then
     exit 1
 else
     echo "CATALINA_HOME is set to $CATALINA_HOME"
+    echo "JAVA_OPTS is set to -Xms2048M -Xmx2048M"
 fi
 
 if [ ! -z "$KYLIN_LD_LIBRARY_PATH" ]
@@ -23,7 +24,8 @@ fi
 #hbase command will do all the dirty tasks for us:
 if [ "$1" = "start" ] ; then
         export HBASE_CLASSPATH_PREFIX=/etc/kylin:${CATALINA_HOME}/bin/bootstrap.jar:${CATALINA_HOME}/bin/tomcat-juli.jar:${CATALINA_HOME}/lib/*:$HBASE_CLASSPATH_PREFIX
-        hbase  -XX:PermSize=256M -XX:MaxPermSize=512M -Djava.util.logging.config.file=${CATALINA_HOME}/conf/logging.properties -Djava.library.path=${KYLIN_LD_LIBRARY_PATH} -Djava.util.logging.manager=org.apache.juli.ClassLoaderLogManager -Dorg.apache.tomcat.util.buf.UDecoder.ALLOW_ENCODED_SLASH=true -Dorg.apache.catalina.connector.CoyoteAdapter.ALLOW_BACKSLASH=true -Dspring.profiles.active=sandbox -Djava.endorsed.dirs=${CATALINA_HOME}/endorsed  -Dcatalina.base=${CATALINA_HOME} -Dcatalina.home=${CATALINA_HOME} -Djava.io.tmpdir=${CATALINA_HOME}/temp  org.apache.hadoop.util.RunJar ${CATALINA_HOME}/bin/bootstrap.jar  org.apache.catalina.startup.Bootstrap start > ${CATALINA_HOME}/logs/kylin.log 2>&1 &
+        export JAVA_OPTS="-Xms2048M -Xmx2048M"
+        hbase  ${JAVA_OPTS}  -XX:PermSize=256M -XX:MaxPermSize=512M -Djava.util.logging.config.file=${CATALINA_HOME}/conf/logging.properties -Djava.library.path=${KYLIN_LD_LIBRARY_PATH} -Djava.util.logging.manager=org.apache.juli.ClassLoaderLogManager -Dorg.apache.tomcat.util.buf.UDecoder.ALLOW_ENCODED_SLASH=true -Dorg.apache.catalina.connector.CoyoteAdapter.ALLOW_BACKSLASH=true -Dspring.profiles.active=sandbox -Djava.endorsed.dirs=${CATALINA_HOME}/endorsed  -Dcatalina.base=${CATALINA_HOME} -Dcatalina.home=${CATALINA_HOME} -Djava.io.tmpdir=${CATALINA_HOME}/temp  org.apache.hadoop.util.RunJar ${CATALINA_HOME}/bin/bootstrap.jar  org.apache.catalina.startup.Bootstrap start > ${CATALINA_HOME}/logs/kylin.log 2>&1 &
         echo "A new Kylin instance is started by $USER, stop it using \"kylin.sh stop\""
         echo "Please visit http://<your_hostname>:7070/kylin to play with the cubes! (Useranme: ADMIN, Password: KYLIN)"
         echo "You can check the log at ${CATALINA_HOME}/logs/kylin.log"


[3/3] incubator-kylin git commit: Merge pull request #449 from vipinkumar7/patch-2

Posted by li...@apache.org.
Merge pull request #449 from vipinkumar7/patch-2

update kylin.sh

Project: http://git-wip-us.apache.org/repos/asf/incubator-kylin/repo
Commit: http://git-wip-us.apache.org/repos/asf/incubator-kylin/commit/07381b83
Tree: http://git-wip-us.apache.org/repos/asf/incubator-kylin/tree/07381b83
Diff: http://git-wip-us.apache.org/repos/asf/incubator-kylin/diff/07381b83

Branch: refs/heads/0.6
Commit: 07381b83249ec8081e67f2fd63dd1137f2c00220
Parents: bfd321d 3cebc63
Author: qianhao.zhou <qi...@ebay.com>
Authored: Wed Mar 11 18:24:26 2015 +0800
Committer: qianhao.zhou <qi...@ebay.com>
Committed: Wed Mar 11 18:24:26 2015 +0800

----------------------------------------------------------------------
 kylin.sh | 4 +++-
 1 file changed, 3 insertions(+), 1 deletion(-)
----------------------------------------------------------------------
diff --git a/job/src/main/java/com/kylinolap/job/hadoop/cube/RangeKeyDistributionReducer.java b/job/src/main/java/com/kylinolap/job/hadoop/cube/RangeKeyDistributionReducer.java
index 242d76d..ed6e773 100644
--- a/job/src/main/java/com/kylinolap/job/hadoop/cube/RangeKeyDistributionReducer.java
+++ b/job/src/main/java/com/kylinolap/job/hadoop/cube/RangeKeyDistributionReducer.java
@@ -35,11 +35,11 @@ import com.kylinolap.metadata.model.cube.CubeDesc.CubeCapacity;
 public class RangeKeyDistributionReducer extends KylinReducer<Text, LongWritable, Text, LongWritable> {
 
     public static final long ONE_GIGA_BYTES = 1024L * 1024L * 1024L;
-    public static final int SMALL_CUT = 10;  //  10 GB per region
-    public static final int MEDIUM_CUT = 20; //  20 GB per region
-    public static final int LARGE_CUT = 100; // 100 GB per region
+    public static final int SMALL_CUT = 5;  //  5 GB per region
+    public static final int MEDIUM_CUT = 10; //  10 GB per region
+    public static final int LARGE_CUT = 50; // 50 GB per region
     
-    public static final int MAX_REGION = 500;
+    public static final int MAX_REGION = 1000;
 
     private LongWritable outputValue = new LongWritable(0);
 


[2/3] incubator-kylin git commit: update kylin.sh

Posted by li...@apache.org.
update kylin.sh 

This is java vm args which is working for complex quries.

Project: http://git-wip-us.apache.org/repos/asf/incubator-kylin/repo
Commit: http://git-wip-us.apache.org/repos/asf/incubator-kylin/commit/3cebc63d
Tree: http://git-wip-us.apache.org/repos/asf/incubator-kylin/tree/3cebc63d
Diff: http://git-wip-us.apache.org/repos/asf/incubator-kylin/diff/3cebc63d

Branch: refs/heads/0.6
Commit: 3cebc63d86e64d620a8e7044cd668dd5a99dae4e
Parents: bfd321d
Author: vipin kumar <vi...@gmail.com>
Authored: Wed Mar 11 13:46:04 2015 +0530
Committer: vipin kumar <vi...@gmail.com>
Committed: Wed Mar 11 13:46:04 2015 +0530

----------------------------------------------------------------------
 kylin.sh | 4 +++-
 1 file changed, 3 insertions(+), 1 deletion(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/incubator-kylin/blob/3cebc63d/kylin.sh
----------------------------------------------------------------------